@@ -1,9 +1,6 @@
 module Sexp = Sexp
 module Sexp_conv = Sexp_conv
 module Sexp_conv_error = Sexp_conv_error
+module Sexp_conv_record = Sexp_conv_record
+module Sexp_grammar = Sexp_grammar
 module Sexpable = Sexpable
-
-module Private = struct
-  module Lazy_group_id = Lazy_group_id
-  module Raw_grammar = Raw_grammar
-end
